<!--
Thank you for creating a PR on hmf!

Please read through the following and check the boxes to ensure
your PR meets our coding standards and that it follows the
correct pathways for testing and deployment.
-->

# Description
<!-- Write a brief description of what the new feature does, and how a review could take it for a spin -->

# Issues
<!-- If this feature is in response to any open issues, reference them here by adding a line for each, with "Fixes #xx".
     Otherwise remove this section.
-->

# Checklist
I have

- [ ] Added a test covering your new feature adequately?
- [ ] Added a docstring (or note to a docstring) describing your feature?
- [ ] (Optional): Added a tutorial / section to a tutorial showing usage of your new feature?
- [ ] **Important**: this feature does *not* break API compatibility.
